==> mono-1.1.7.tar.gz: mono-1.1.7/mcs/class/corlib/System.Runtime.ConstrainedExecution/ReliabilityContractAttribute.cs <==
//
// System.Runtime.ConstrainedExecution.ReliabilityContractAttribute.cs
//
// Author:
//    Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//

#if NET_2_0

using System.Runtime.InteropServices;

namespace System.Runtime.ConstrainedExecution
{
	[AttributeUsage ((AttributeTargets.Assembly | AttributeTargets.Class | AttributeTargets.Struct |
		AttributeTargets.Constructor | AttributeTargets.Method | AttributeTargets.Interface), Inherited=false)]
	[ComVisible (false)]
        public sealed class ReliabilityContractAttribute : Attribute
        {
                Consistency consistency;
                CER cer;
                
                public ReliabilityContractAttribute ()
                {
                }

                public ReliabilityContractAttribute (Consistency consistency, CER cer)
                {
                        this.consistency = consistency;
                        this.cer = cer;
                }

                public CER CER {
                        get { return cer; }
			set { cer = value; }
                }

                public Consistency ConsistencyGuarantee {

                        get { return consistency; }

                        set { consistency = value; }
                }
        }
}
#endif

==> mono-1.1.9.2.tar.gz: mono-1.1.9.2/mcs/class/corlib/System.Runtime.ConstrainedExecution/ReliabilityContractAttribute.cs <==
//
// System.Runtime.ConstrainedExecution.ReliabilityContractAttribute.cs
//
// Author:
//    Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0

namespace System.Runtime.ConstrainedExecution
{
	[AttributeUsage ((AttributeTargets.Assembly | AttributeTargets.Class | AttributeTargets.Struct |
		AttributeTargets.Constructor | AttributeTargets.Method | AttributeTargets.Interface), Inherited=false)]
        public sealed class ReliabilityContractAttribute : Attribute
        {
                Consistency consistency;
                Cer cer;

		[Obsolete ()]
                public ReliabilityContractAttribute ()
                {
                }

                public ReliabilityContractAttribute (Consistency consistency, Cer cer)
                {
                        this.consistency = consistency;
                        this.cer = cer;
                }

                public Cer Cer {
                        get { return cer; }
                }

                public Consistency ConsistencyGuarantee {
			get { return consistency; }
                }
        }
}
#endif
